
///////////////////////////////////////////////////////////////////////////////////////////////////
// Прикладной интерфейс

Перем Лог;

// Интерфейсная процедура, выполняет регистрацию команды и настройку парсера командной строки
//   
// Параметры:
//   ИмяКоманды 	- Строка										- Имя регистрируемой команды
//   Парсер 		- ПарсерАргументовКоманднойСтроки (cmdline)		- Парсер командной строки
//
Процедура ЗарегистрироватьКоманду(Знач ИмяКоманды, Знач Парсер) Экспорт
	
	ОписаниеКоманды = Парсер.ОписаниеКоманды(ИмяКоманды, "Подключить сетевой диск");

	Парсер.ДобавитьИменованныйПараметрКоманды(ОписаниеКоманды, 
		"-params",
		"Файлы JSON содержащие значения параметров,
		|могут быть указаны несколько файлов разделенные "";""
		|(параметры командной строки имеют более высокий приоритет)");

	Парсер.ДобавитьИменованныйПараметрКоманды(ОписаниеКоманды, 
		"-map-drive",
		"Имя устройства (буква диска)");

	Парсер.ДобавитьИменованныйПараметрКоманды(ОписаниеКоманды, 
		"-map-res",
		"Путь к подключаемому ресурсу");

	Парсер.ДобавитьИменованныйПараметрКоманды(ОписаниеКоманды, 
		"-map-user",
		"Пользователь для подключения");

	Парсер.ДобавитьИменованныйПараметрКоманды(ОписаниеКоманды, 
		"-map-pwd",
		"Пароль для подключения");

    Парсер.ДобавитьКоманду(ОписаниеКоманды);

КонецПроцедуры // ЗарегистрироватьКоманду()

// Интерфейсная процедура, выполняет текущую команду
//   
// Параметры:
//   ПараметрыКоманды 	- Соответствие						- Соответствие параметров команды и их значений
//
// Возвращаемое значение:
//	Число - код возврата команды
//
Функция ВыполнитьКоманду(Знач ПараметрыКоманды) Экспорт
    
	ЗапускПриложений.ПрочитатьПараметрыКомандыИзФайла(ПараметрыКоманды["-params"], ПараметрыКоманды);
	
	ИмяУстройства		= ПараметрыКоманды["-map-drive"];
	ИмяРесурса			= ПараметрыКоманды["-map-res"];
	Пользователь		= ПараметрыКоманды["-map-user"];
	ПарольПользователя	= ПараметрыКоманды["-map-pwd"];

	ВозможныйРезультат = МенеджерКомандПриложения.РезультатыКоманд();

	Если ПустаяСтрока(ИмяУстройства) Тогда
		Лог.Ошибка("Не указано имя устройства");
		Возврат ВозможныйРезультат.НеверныеПараметры;
	КонецЕсли;

	Если ПустаяСтрока(ИмяРесурса) Тогда
		Лог.Ошибка("Не указано имя подключаемого ресурса");
		Возврат ВозможныйРезультат.НеверныеПараметры;
	КонецЕсли;

	Попытка
		ОписаниеРезультата = "";
		
		Результат = ПодключитьДиск(ИмяУстройства, ИмяРесурса, Пользователь, ПарольПользователя, ОписаниеРезультата);

		Если Не ПустаяСтрока(ОписаниеРезультата) Тогда
			Лог.Информация("Вывод команды: " + ОписаниеРезультата);
		КонецЕсли;
		
		Если НЕ Результат Тогда
			Возврат ВозможныйРезультат.ОшибкаВремениВыполнения;
		КонецЕсли;

		Возврат ВозможныйРезультат.Успех;
	Исключение
		Лог.Ошибка("Вывод команды: " + ОписаниеРезультата + Символы.ПС + ОписаниеОшибки());
		Возврат ВозможныйРезультат.ОшибкаВремениВыполнения;
	КонецПопытки;

КонецФункции // ВыполнитьКоманду()

// Функция отключает указанный сетевой диск
//   
// Параметры:
//   ИмяУстройства 			- Строка		- имя (буква) подключаемого диска
//   ИмяРесурса 			- Строка		- сетевой путь к подключаемому ресурсу
//   Пользователь 			- Строка		- пользователь от имени которого выполняется подключение
//   ПарольПользователя		- Строка		- пароль пользователя от имени которого выполняется подключение
//   ОписаниеРезультата 	- Строка		- результат выполнения команды
//
// Возвращаемое значение:
//	Булево - Истина - Команда выполнена успешно
//
Функция ПодключитьДиск(ИмяУстройства, ИмяРесурса, Пользователь, ПарольПользователя, ОписаниеРезультата = "") Экспорт

	КомандаРК = Новый Команда;
	
	КомандаРК.УстановитьКоманду("net");
	КомандаРК.ДобавитьПараметр("use");
	КомандаРК.ДобавитьПараметр(ИмяУстройства);
	КомандаРК.ДобавитьПараметр(ИмяРесурса);
	КомандаРК.ДобавитьПараметр(ПарольПользователя);
	КомандаРК.ДобавитьПараметр("/USER:" + Пользователь);

	КомандаРК.УстановитьИсполнениеЧерезКомандыСистемы( Ложь );
	КомандаРК.ПоказыватьВыводНемедленно( Ложь );
	
	КодВозврата = КомандаРК.Исполнить();

	ОписаниеРезультата = КомандаРК.ПолучитьВывод();
	
	Возврат КодВозврата = 0;
	
КонецФункции // ПодключитьДиск()

Лог = Логирование.ПолучитьЛог("ktb.app.cpdb");